@@ -1,29 +1,22 @@
-# -*- coding: utf-8 -*-
+"""Task Annotations.
+
+Annotations is a nice term for monkey-patching task classes
+in the configuration.
+
+This prepares and performs the annotations in the
+:setting:`task_annotations` setting.
 """
-    celery.app.annotations
-    ~~~~~~~~~~~~~~~~~~~~~~
-
-    Annotations is a nice term for moneky patching
-    task classes in the configuration.
-
-    This prepares and performs the annotations in the
-    :setting:`CELERY_ANNOTATIONS` setting.
-
-"""
-from __future__ import absolute_import
-
-from celery.utils.functional import firstmethod, mpromise
+from celery.utils.functional import firstmethod, mlazy
 from celery.utils.imports import instantiate
 
 _first_match = firstmethod('annotate')
 _first_match_any = firstmethod('annotate_any')
 
-
-def resolve_all(anno, task):
-    return (r for r in (_first_match(anno, task), _first_match_any(anno)) if r)
+__all__ = ('MapAnnotation', 'prepare', 'resolve_all')
 
 
 class MapAnnotation(dict):
+    """Annotation map: task_name => attributes."""
 
     def annotate_any(self):
         try:
@@ -39,17 +32,21 @@ class MapAnnotation(dict):
 
 
 def prepare(annotations):
-    """Expands the :setting:`CELERY_ANNOTATIONS` setting."""
-
+    """Expand the :setting:`task_annotations` setting."""
     def expand_annotation(annotation):
         if isinstance(annotation, dict):
             return MapAnnotation(annotation)
-        elif isinstance(annotation, basestring):
-            return mpromise(instantiate, annotation)
+        elif isinstance(annotation, str):
+            return mlazy(instantiate, annotation)
         return annotation
 
     if annotations is None:
         return ()
     elif not isinstance(annotations, (list, tuple)):
-        annotations = (annotations, )
+        annotations = (annotations,)
     return [expand_annotation(anno) for anno in annotations]
+
+
+def resolve_all(anno, task):
+    """Resolve all pending annotations."""
+    return (x for x in (_first_match(anno, task), _first_match_any(anno)) if x)
