@@ -19,8 +19,7 @@ from celery._state import get_current_task
 from celery.exceptions import CDeprecationWarning, CPendingDeprecationWarning
 from celery.local import class_property
 from celery.platforms import isatty
-from celery.utils.log import (ColorFormatter, LoggingProxy, get_logger,
-                              get_multiprocessing_logger, mlevel,
+from celery.utils.log import (ColorFormatter, LoggingProxy, get_logger, get_multiprocessing_logger, mlevel,
                               reset_multiprocessing_logger)
 from celery.utils.nodenames import node_format
 from celery.utils.term import colored
@@ -65,9 +64,8 @@ class Logging:
         handled = self.setup_logging_subsystem(
             loglevel, logfile, colorize=colorize, hostname=hostname,
         )
-        if not handled:
-            if redirect_stdouts:
-                self.redirect_stdouts(redirect_level)
+        if not handled and redirect_stdouts:
+            self.redirect_stdouts(redirect_level)
         os.environ.update(
             CELERY_LOG_LEVEL=str(loglevel) if loglevel else '',
             CELERY_LOG_FILE=str(logfile) if logfile else '',
