@@ -16,9 +16,10 @@ from celery.utils.serialization import UnpickleableExceptionWrapper
 from celery.worker import state as worker_state
 
 from .conftest import TEST_BACKEND, get_active_redis_channels, get_redis_connection
-from .tasks import (ClassBasedAutoRetryTask, ExpectedException, add, add_ignore_result, add_not_typed, fail,
-                    fail_unpickleable, print_unicode, retry, retry_once, retry_once_headers, retry_once_priority,
-                    retry_unpickleable, return_properties, second_order_replace1, sleeping)
+from .tasks import (ClassBasedAutoRetryTask, ExpectedException, add, add_ignore_result, add_not_typed, add_pydantic,
+                    fail, fail_unpickleable, print_unicode, retry, retry_once, retry_once_headers,
+                    retry_once_priority, retry_unpickleable, return_properties, second_order_replace1, sleeping,
+                    soft_time_limit_must_exceed_time_limit)
 
 TIMEOUT = 10
 
@@ -128,6 +129,20 @@ class test_tasks:
         sleep(1)
         assert result.result is None
 
+    @flaky
+    def test_pydantic_annotations(self, manager):
+        """Tests task call with Pydantic model serialization."""
+        results = []
+        # Tests calling task only with args
+        for i in range(10):
+            results.append([i + i, add_pydantic.delay({'x': i, 'y': i})])
+        for expected, result in results:
+            value = result.get(timeout=10)
+            assert value == {'result': expected}
+            assert result.status == 'SUCCESS'
+            assert result.ready() is True
+            assert result.successful() is True
+
     @flaky
     def test_timeout(self, manager):
         """Testing timeout of getting results from tasks."""
@@ -303,6 +318,17 @@ class test_tasks:
                     assert result.successful() is False
             worker_state.revoked_stamps.clear()
 
+    @flaky
+    def test_revoke_by_stamped_headers_no_match(self, manager):
+        response = manager.app.control.revoke_by_stamped_headers(
+            {"myheader": ["myvalue"]},
+            terminate=False,
+            reply=True,
+        )
+
+        expected_response = "headers {'myheader': ['myvalue']} flagged as revoked, but not terminated"
+        assert response[0][list(response[0].keys())[0]]["ok"] == expected_response
+
     @flaky
     def test_wrong_arguments(self, manager):
         """Tests that proper exceptions are raised when task is called with wrong arguments."""
@@ -459,6 +485,15 @@ class test_tasks:
         res = return_properties.apply_async(app_id="1234")
         assert res.get(timeout=TIMEOUT)["app_id"] == "1234"
 
+    @flaky
+    def test_soft_time_limit_exceeding_time_limit(self):
+
+        with pytest.raises(ValueError, match='soft_time_limit must be less than or equal to time_limit'):
+            result = soft_time_limit_must_exceed_time_limit.apply_async()
+            result.get(timeout=5)
+
+            assert result.status == 'FAILURE'
+
 
 class test_trace_log_arguments:
     args = "CUSTOM ARGS"
