@@ -760,7 +760,7 @@ class test_KeyValueStoreBackend:
         assert self.b._strip_prefix('x1b34') == 'x1b34'
 
     def test_global_keyprefix(self):
-        global_keyprefix = "test_global_keyprefix_"
+        global_keyprefix = "test_global_keyprefix"
         app = copy.deepcopy(self.app)
         app.conf.get('result_backend_transport_options', {}).update({"global_keyprefix": global_keyprefix})
         b = KVBackend(app=app)
@@ -769,6 +769,24 @@ class test_KeyValueStoreBackend:
         assert bytes_to_str(b.get_key_for_group(tid)) == f"{global_keyprefix}_celery-taskset-meta-{tid}"
         assert bytes_to_str(b.get_key_for_chord(tid)) == f"{global_keyprefix}_chord-unlock-{tid}"
 
+        global_keyprefix = "test_global_keyprefix_"
+        app = copy.deepcopy(self.app)
+        app.conf.get('result_backend_transport_options', {}).update({"global_keyprefix": global_keyprefix})
+        b = KVBackend(app=app)
+        tid = uuid()
+        assert bytes_to_str(b.get_key_for_task(tid)) == f"{global_keyprefix}celery-task-meta-{tid}"
+        assert bytes_to_str(b.get_key_for_group(tid)) == f"{global_keyprefix}celery-taskset-meta-{tid}"
+        assert bytes_to_str(b.get_key_for_chord(tid)) == f"{global_keyprefix}chord-unlock-{tid}"
+
+        global_keyprefix = "test_global_keyprefix:"
+        app = copy.deepcopy(self.app)
+        app.conf.get('result_backend_transport_options', {}).update({"global_keyprefix": global_keyprefix})
+        b = KVBackend(app=app)
+        tid = uuid()
+        assert bytes_to_str(b.get_key_for_task(tid)) == f"{global_keyprefix}celery-task-meta-{tid}"
+        assert bytes_to_str(b.get_key_for_group(tid)) == f"{global_keyprefix}celery-taskset-meta-{tid}"
+        assert bytes_to_str(b.get_key_for_chord(tid)) == f"{global_keyprefix}chord-unlock-{tid}"
+
     def test_global_keyprefix_missing(self):
         tid = uuid()
         assert bytes_to_str(self.b.get_key_for_task(tid)) == f"celery-task-meta-{tid}"
