@@ -1,24 +1,13 @@
-import sys
 from datetime import datetime, timedelta
 from unittest.mock import MagicMock, Mock, call, patch
 
 import pytest
 from google.cloud.exceptions import NotFound
 
+from celery.backends.gcs import GCSBackend
 from celery.exceptions import ImproperlyConfigured
 
-# Workaround until python-firestore is fixed
-is_py313 = sys.version_info >= (3, 13)
-if not is_py313:
-    from celery.backends.gcs import GCSBackend
-else:
-    GCSBackend = None
 
-
-@pytest.mark.skipif(
-    is_py313,
-    reason="https://github.com/googleapis/python-firestore/issues/973",
-)
 class test_GCSBackend:
     def setup_method(self):
         self.app.conf.gcs_bucket = 'bucket'
