@@ -1,4 +1,5 @@
 import errno
+import logging
 import socket
 from collections import deque
 from unittest.mock import MagicMock, Mock, call, patch
@@ -11,6 +12,7 @@ from celery import bootsteps
 from celery.contrib.testing.mocks import ContextMock
 from celery.exceptions import WorkerShutdown, WorkerTerminate
 from celery.utils.collections import LimitedSet
+from celery.utils.quorum_queues import detect_quorum_queues
 from celery.worker.consumer.agent import Agent
 from celery.worker.consumer.consumer import CANCEL_TASKS_BY_DEFAULT, CLOSE, TERMINATE, Consumer
 from celery.worker.consumer.gossip import Gossip
@@ -46,6 +48,7 @@ class test_Consumer(ConsumerTestCase):
         @self.app.task(shared=False)
         def add(x, y):
             return x + y
+
         self.add = add
 
     def test_repr(self):
@@ -146,6 +149,7 @@ class test_Consumer(ConsumerTestCase):
 
             def __exit__(self, *args):
                 pass
+
         c.qos._mutex = MutexMock()
 
         assert c._restore_prefetch_count_after_connection_restart(None) is None
@@ -265,6 +269,7 @@ class test_Consumer(ConsumerTestCase):
         def se(*args, **kwargs):
             c.blueprint.state = CLOSE
             raise RestartFreqExceeded()
+
         c._restart_state.step.side_effect = se
         c.blueprint.start.side_effect = socket.error()
 
@@ -312,6 +317,7 @@ class test_Consumer(ConsumerTestCase):
     def _closer(self, c):
         def se(*args, **kwargs):
             c.blueprint.state = CLOSE
+
         return se
 
     @pytest.mark.parametrize("broker_connection_retry", [True, False])
@@ -442,6 +448,31 @@ class test_Consumer(ConsumerTestCase):
         with pytest.deprecated_call(match=CANCEL_TASKS_BY_DEFAULT):
             c.on_connection_error_after_connected(Mock())
 
+    @pytest.mark.usefixtures('depends_on_current_app')
+    def test_cancel_all_unacked_requests(self):
+        c = self.get_consumer()
+
+        mock_request_acks_late_not_acknowledged = Mock(id='1')
+        mock_request_acks_late_not_acknowledged.task.acks_late = True
+        mock_request_acks_late_not_acknowledged.acknowledged = False
+        mock_request_acks_late_acknowledged = Mock(id='2')
+        mock_request_acks_late_acknowledged.task.acks_late = True
+        mock_request_acks_late_acknowledged.acknowledged = True
+        mock_request_acks_early = Mock(id='3')
+        mock_request_acks_early.task.acks_late = False
+
+        active_requests.add(mock_request_acks_late_not_acknowledged)
+        active_requests.add(mock_request_acks_late_acknowledged)
+        active_requests.add(mock_request_acks_early)
+
+        c.cancel_all_unacked_requests()
+
+        mock_request_acks_late_not_acknowledged.cancel.assert_called_once_with(c.pool)
+        mock_request_acks_late_acknowledged.cancel.assert_not_called()
+        mock_request_acks_early.cancel.assert_called_once_with(c.pool)
+
+        active_requests.clear()
+
     @pytest.mark.parametrize("broker_connection_retry", [True, False])
     @pytest.mark.parametrize("broker_connection_retry_on_startup", [None, False])
     @pytest.mark.parametrize("first_connection_attempt", [True, False])
@@ -452,12 +483,12 @@ class test_Consumer(ConsumerTestCase):
         c.app.conf.broker_connection_retry_on_startup = broker_connection_retry_on_startup
         c.app.conf.broker_connection_retry = broker_connection_retry
 
-        if broker_connection_retry_on_startup is None:
-            with subtests.test("Deprecation warning when startup is None"):
-                with pytest.deprecated_call():
-                    c.ensure_connected(Mock())
-
         if broker_connection_retry is False:
+            if broker_connection_retry_on_startup is None:
+                with subtests.test("Deprecation warning when startup is None"):
+                    with pytest.deprecated_call():
+                        c.ensure_connected(Mock())
+
             with subtests.test("Does not retry when connect throws an error and retry is set to false"):
                 conn = Mock()
                 conn.connect.side_effect = ConnectionError()
@@ -504,6 +535,61 @@ class test_Consumer_WorkerShutdown(ConsumerTestCase):
             assert expected_connection_retry_type in record.msg
 
 
+class test_Consumer_PerformPendingOperations(ConsumerTestCase):
+
+    def test_perform_pending_operations_all_success(self):
+        """
+        Test that all pending operations are processed successfully when `once=False`.
+        """
+        c = self.get_consumer(no_hub=True)
+
+        # Create mock operations
+        mock_operation_1 = Mock()
+        mock_operation_2 = Mock()
+
+        # Add mock operations to _pending_operations
+        c._pending_operations = [mock_operation_1, mock_operation_2]
+
+        # Call perform_pending_operations
+        c.perform_pending_operations()
+
+        # Assert that all operations were called
+        mock_operation_1.assert_called_once()
+        mock_operation_2.assert_called_once()
+
+        # Ensure all pending operations are cleared
+        assert len(c._pending_operations) == 0
+
+    def test_perform_pending_operations_with_exception(self):
+        """
+        Test that pending operations are processed even if one raises an exception, and
+        the exception is logged when `once=False`.
+        """
+        c = self.get_consumer(no_hub=True)
+
+        # Mock operations: one failing, one successful
+        mock_operation_fail = Mock(side_effect=Exception("Test Exception"))
+        mock_operation_success = Mock()
+
+        # Add operations to _pending_operations
+        c._pending_operations = [mock_operation_fail, mock_operation_success]
+
+        # Patch logger to avoid logging during the test
+        with patch('celery.worker.consumer.consumer.logger.exception') as mock_logger:
+            # Call perform_pending_operations
+            c.perform_pending_operations()
+
+            # Assert that both operations were attempted
+            mock_operation_fail.assert_called_once()
+            mock_operation_success.assert_called_once()
+
+            # Ensure the exception was logged
+            mock_logger.assert_called_once()
+
+            # Ensure all pending operations are cleared
+            assert len(c._pending_operations) == 0
+
+
 class test_Heart:
 
     def test_start(self):
@@ -543,8 +629,13 @@ class test_Heart:
 
 class test_Tasks:
 
+    def setup_method(self):
+        self.c = Mock()
+        self.c.app.conf.worker_detect_quorum_queues = True
+        self.c.connection.qos_semantics_matches_spec = False
+
     def test_stop(self):
-        c = Mock()
+        c = self.c
         tasks = Tasks(c)
         assert c.task_consumer is None
         assert c.qos is None
@@ -553,10 +644,68 @@ class test_Tasks:
         tasks.stop(c)
 
     def test_stop_already_stopped(self):
-        c = Mock()
+        c = self.c
         tasks = Tasks(c)
         tasks.stop(c)
 
+    def test_detect_quorum_queues_positive(self):
+        c = self.c
+        self.c.connection.transport.driver_type = 'amqp'
+        c.app.amqp.queues = {"celery": Mock(queue_arguments={"x-queue-type": "quorum"})}
+        result, name = detect_quorum_queues(c.app, c.connection.transport.driver_type)
+        assert result
+        assert name == "celery"
+
+    def test_detect_quorum_queues_negative(self):
+        c = self.c
+        self.c.connection.transport.driver_type = 'amqp'
+        c.app.amqp.queues = {"celery": Mock(queue_arguments=None)}
+        result, name = detect_quorum_queues(c.app, c.connection.transport.driver_type)
+        assert not result
+        assert name == ""
+
+    def test_detect_quorum_queues_not_rabbitmq(self):
+        c = self.c
+        self.c.connection.transport.driver_type = 'redis'
+        result, name = detect_quorum_queues(c.app, c.connection.transport.driver_type)
+        assert not result
+        assert name == ""
+
+    def test_qos_global_worker_detect_quorum_queues_false(self):
+        c = self.c
+        c.app.conf.worker_detect_quorum_queues = False
+        tasks = Tasks(c)
+        assert tasks.qos_global(c) is True
+
+    def test_qos_global_worker_detect_quorum_queues_true_no_quorum_queues(self):
+        c = self.c
+        c.app.amqp.queues = {"celery": Mock(queue_arguments=None)}
+        tasks = Tasks(c)
+        assert tasks.qos_global(c) is True
+
+    def test_qos_global_worker_detect_quorum_queues_true_with_quorum_queues(self):
+        c = self.c
+        self.c.connection.transport.driver_type = 'amqp'
+        c.app.amqp.queues = {"celery": Mock(queue_arguments={"x-queue-type": "quorum"})}
+        tasks = Tasks(c)
+        assert tasks.qos_global(c) is False
+
+    def test_log_when_qos_is_false(self, caplog):
+        c = self.c
+        c.connection.transport.driver_type = 'amqp'
+        c.app.conf.broker_native_delayed_delivery = True
+        c.app.amqp.queues = {"celery": Mock(queue_arguments={"x-queue-type": "quorum"})}
+        tasks = Tasks(c)
+
+        with caplog.at_level(logging.INFO):
+            tasks.start(c)
+
+        assert len(caplog.records) == 1
+
+        record = caplog.records[0]
+        assert record.levelname == "INFO"
+        assert record.msg == "Global QoS is disabled. Prefetch count in now static."
+
 
 class test_Agent:
 
