@@ -1,4 +1,7 @@
+import os
 import pickle
+import sys
+from importlib import import_module
 from time import time
 from unittest.mock import Mock, patch
 
@@ -16,6 +19,7 @@ def reset_state():
     yield
     state.active_requests.clear()
     state.revoked.clear()
+    state.revoked_stamps.clear()
     state.total_count.clear()
 
 
@@ -41,7 +45,7 @@ class MyPersistent(state.Persistent):
 
 class test_maybe_shutdown:
 
-    def teardown(self):
+    def teardown_method(self):
         state.should_stop = None
         state.should_terminate = None
 
@@ -187,3 +191,32 @@ class test_state:
         for request in requests:
             state.task_ready(request)
         assert len(state.active_requests) == 0
+
+
+class test_state_configuration():
+
+    @staticmethod
+    def import_state():
+        with patch.dict(sys.modules):
+            del sys.modules['celery.worker.state']
+            return import_module('celery.worker.state')
+
+    @patch.dict(os.environ, {
+        'CELERY_WORKER_REVOKES_MAX': '50001',
+        'CELERY_WORKER_SUCCESSFUL_MAX': '1001',
+        'CELERY_WORKER_REVOKE_EXPIRES': '10801',
+        'CELERY_WORKER_SUCCESSFUL_EXPIRES': '10801',
+    })
+    def test_custom_configuration(self):
+        state = self.import_state()
+        assert state.REVOKES_MAX == 50001
+        assert state.SUCCESSFUL_MAX == 1001
+        assert state.REVOKE_EXPIRES == 10801
+        assert state.SUCCESSFUL_EXPIRES == 10801
+
+    def test_default_configuration(self):
+        state = self.import_state()
+        assert state.REVOKES_MAX == 50000
+        assert state.SUCCESSFUL_MAX == 1000
+        assert state.REVOKE_EXPIRES == 10800
+        assert state.SUCCESSFUL_EXPIRES == 10800
